@@ -9,7 +9,7 @@ from sqlalchemy_utils import functions as sqlalchemy_utils
 
 
 class Connection:
-    engine: Engine
+    _engine: Engine = None
 
     @classmethod
     def execute_query(cls, query: str, params: dict | list[dict] = None) -> None:
@@ -44,7 +44,7 @@ class Connection:
     @classmethod
     def _execute(cls, query: str, params: dict | list[dict] = None, _result: bool = False) -> None | CursorResult:
         """Execute query with params, Privately"""
-        with cls.engine.connect() as connection:
+        with cls._engine.connect() as connection:
             cur = connection.execute(sqlalchemy.text(query), params)
 
             if _result:
@@ -55,22 +55,22 @@ class Connection:
     @classmethod
     def create_database(cls):
         """Create database if not exists"""
-        if not sqlalchemy_utils.database_exists(cls.engine.url):
-            sqlalchemy_utils.create_database(cls.engine.url)
+        if not sqlalchemy_utils.database_exists(cls._engine.url):
+            sqlalchemy_utils.create_database(cls._engine.url)
 
     @classmethod
     def drop_database(cls):
         """Drop database if not exists"""
-        if sqlalchemy_utils.database_exists(cls.engine.url):
-            sqlalchemy_utils.drop_database(cls.engine.url)
+        if sqlalchemy_utils.database_exists(cls._engine.url):
+            sqlalchemy_utils.drop_database(cls._engine.url)
 
     @classmethod
     def verify(cls):
         """Check connection works"""
-        if not cls.engine:
+        if not cls._engine:
             raise ValueError("The engine is not defined")
 
-        with cls.engine.connect() as con:
+        with cls._engine.connect() as con:
             pass
 
 
@@ -80,8 +80,8 @@ else:
     if not environ.get("DB_CONN"):
         raise ValueError("DB_CONN not set")
 
-    if Connection.engine:
+    if Connection._engine:
         raise ValueError("The engine is already defined")
 
-    Connection.engine = sqlalchemy.create_engine(environ.get("DB_CONN"), poolclass=QueuePool)
+    Connection._engine = sqlalchemy.create_engine(environ.get("DB_CONN"), poolclass=QueuePool)
     Connection()  # Check creates
